@@ -84,6 +84,9 @@
 #'noncompliant, 1 for compliant. If this argument is specified, the formula must also
 #'include the compliance variable.
 #'@param ndpost number of draws from the posterior
+#'
+#'@param model_prior specifices the prior probability of exchangebility of data sources. Details for priors
+#'are given in Boatman et al. (2020).
 #'@param ... additional arguments passed to BART
 #'
 #'@return
@@ -144,9 +147,12 @@
 #'Kaizer, Alexander M., Koopmeiners, Joseph S., Hobbs, Brian P. (2018) Bayesian
 #' hierarchical modeling based on multisource exchangeability. Biostatistics,
 #' 19(2): 169-184.
+#'
+#' Boatman, Jeffrey A., Vock, David. M, and Koopmeiners, Joseph S. (2020) Borrowing from
+#' Supplemental Sources to Estimate Causal Effects from a Primary Data Source. arXiv:2003.09680
 pate <- function(formula, estimator = c("BART", "bayesian_lm"), data, src_var,
   primary_source, exch_prob, trt_var,
-  compliance_var, ndpost = 1e3, ...) {
+  compliance_var, ndpost = 1e3, model_prior= c("none", "power", "powerlog"), ...) {
 
   cl <- match.call()
   mf <- match.call(expand.dots = FALSE)
@@ -155,6 +161,7 @@ pate <- function(formula, estimator = c("BART", "bayesian_lm"), data, src_var,
   # force(formula)
   # force(data)
   estimator <- match.arg(estimator)
+  model_prior <- match.arg(model_prior)
   nc <- !missing(compliance_var)
 
   # these don't work
@@ -288,6 +295,16 @@ pate <- function(formula, estimator = c("BART", "bayesian_lm"), data, src_var,
       stop("'length(exch_prob)' must equal the number of sources minus 1")
   }
 
+  # model_prior stuff
+  p <- ncol(fac)
+  if (model_prior == "power") {
+    ep <- (1 / 2) ^ (p + 1) # + 1 for intercept
+    exch_prob <- rep(ep, nl - 1)
+  } else if (model_prior == "powerlog") {
+    ep <- (1 / 2) ^ (log2(p + 1)) # + 1 for intercept
+    exch_prob <- rep(ep, nl - 1)
+  }
+
 
   # shouldnt be necessary after updating the handling of the data
   # arg with the call to model.frame
